#include "Adafruit_WS2801.h"
#include "SPI.h" // Comment out this line if using Trinket or Gemma
#ifdef __AVR_ATtiny85__
 #include <avr/power.h>
#endif
#include "RGBdriver.h"
#define NUMPIXELS 25


/*****************************************************************************
Example sketch for driving Adafruit WS2801 pixels!

  Designed specifically to work with the Adafruit RGB Pixels!
  12mm Bullet shape ----> https://www.adafruit.com/products/322
  12mm Flat shape   ----> https://www.adafruit.com/products/738
  36mm Square shape ----> https://www.adafruit.com/products/683

  These pixels use SPI to transmit the color data, and have built in
  high speed PWM drivers for 24 bit color per pixel
  2 pins are required to interface

  Adafruit invests time and resources providing this open source code, 
  please support Adafruit and open-source hardware by purchasing 
  products from Adafruit!

  Written by Limor Fried/Ladyada for Adafruit Industries.  
  BSD license, all text above must be included in any redistribution

*****************************************************************************/

// Choose which 2 pins you will use for output.
// Can be any valid output pins.
// The colors of the wires may be totally different so
// BE SURE TO CHECK YOUR PIXELS TO SEE WHICH WIRES TO USE!
uint8_t dataPin  = 5;    // Yellow wire on Adafruit Pixels
uint8_t clockPin = 4;    // Green wire on Adafruit Pixels

// Don't forget to connect the ground wire to Arduino ground,
// and the +5V wire to a +5V supply

// Set the first variable to the NUMBER of pixels. 25 = 25 pixels in a row
Adafruit_WS2801 strip = Adafruit_WS2801(50, 5, 4);
Adafruit_WS2801 strip1 = Adafruit_WS2801(50, 3, 2);
RGBdriver strandDriver(6,7);

// Optional: leave off pin numbers to use hardware SPI
// (pinout is then specific to each board and can't be changed)
//Adafruit_WS2801 strip = Adafruit_WS2801(25);

// For 36mm LED pixels: these pixels internally represent color in a
// different format.  Either of the above constructors can accept an
// optional extra parameter: WS2801_RGB is 'conventional' RGB order
// WS2801_GRB is the GRB order required by the 36mm pixels.  Other
// than this parameter, your code does not need to do anything different;
// the library will handle the format change.  Examples:
// Adafruit_WS2801 strip = Adafruit_WS2801(25, dataPin, clockPin, WS2801_GRB);
// Adafruit_WS2801 strip = Adafruit_WS2801(25, WS2801_GRB);

void sendBLACKPixels(void) {
    strandDriver.begin();
    for (int pixel = 0; pixel <= NUMPIXELS; pixel++) {
        strandDriver.SetColor(0,0,0);
    }
    strandDriver.end();
}

void sendREDPixels(void) {
    strandDriver.begin();
    for (int pixel = 0; pixel < NUMPIXELS; pixel++) {
        strandDriver.SetColor(0,0,255);
    }
    strandDriver.end();
}


void setup() {
    pinMode(2, OUTPUT);
    pinMode(3, OUTPUT);
    pinMode(4, OUTPUT);
    pinMode(5, OUTPUT);
    pinMode(7, OUTPUT);
    pinMode(8, OUTPUT);
    pinMode(9, OUTPUT);
    pinMode(10, OUTPUT);
    pinMode(11, OUTPUT);
    pinMode(12, OUTPUT);
    pinMode(13, OUTPUT);
    pinMode(A0, INPUT);
    Serial.begin(9600);
#if defined(__AVR_ATtiny85__) && (F_CPU == 16000000L)
    clock_prescale_set(clock_div_1); // Enable 16 MHz on Trinket
#endif

    strip.begin();
    strip1.begin();

    // Update LED contents, to start they are all 'off'
    strip.show();
    strip1.show();
    sendREDPixels();
}


void loop() {
    rainbow(100);
}

void xxloop() {
  // Some example procedures showing how to display to the pixels
    //int sensorValue = analogRead(A0);  
    //if (sensorValue < 300) {
    //    colorWipe(Color(255, 0, 0), 100);  colorWipe(Color(0, 0, 0), 100);
    //} else {
        rainbow(100);
        colorWipe(Color(255, 0, 0), 100);  colorWipe(Color(0, 255, 0), 100);
        rainbowCycle(100);
        colorWipe(Color(0, 255, 0), 100);
        colorWipe(Color(255, 0, 0), 100);
        colorWipe(Color(0, 255, 0), 100);
    //}
}

void rainbowWhole(uint8_t wait) {
   for (int j=0; j < 255; j++) {     // 3 cycles of all 256 colors in the wheel
      int c = Wheel(j % 256);

      for (int i=0; i < strip.numPixels(); i++) {
        strip.setPixelColor(i, c);
        strip1.setPixelColor(i, c);
      }
      strip.show();
      strip1.show();
      delay(wait);
    }
}

void rainbow(uint8_t wait) {  
  for (int j=0; j < 256; j++) {     // 3 cycles of all 256 colors in the wheel
    for (int i=0; i < strip.numPixels(); i++) {
      for (int x=0; x < strip.numPixels(); x++) {
        strip.setPixelColor(x, Wheel( (i + j) % 255));
        strip1.setPixelColor(x, Wheel( (i + j) % 255));
      }
    }  
      strip.show();   // write all the pixels out
      strip1.show();   // write all the pixels out
     delay(wait);

  }
}

// Slightly different, this one makes the rainbow wheel equally distributed 
// along the chain
void rainbowCycle(uint8_t wait) { 
  for (int j=0; j < 256 * 5; j++) {     // 5 cycles of all 25 colors in the wheel
    for (int i=0; i < strip.numPixels(); i++) {
      // tricky math! we use each pixel as a fraction of the full 96-color wheel
      // (thats the i / strip.numPixels() part)
      // Then add in j which makes the colors go around per pixel
      // the % 96 is to make the wheel cycle around
      strip.setPixelColor(i, Wheel( ((i * 256 / strip.numPixels()) + j) % 256) );
      strip1.setPixelColor(i, Wheel( ((i * 256 / strip.numPixels()) + j) % 256) );
    }  
    strip.show();   // write all the pixels out
    strip1.show();   // write all the pixels out
    delay(wait);
  }
}

// fill the dots one after the other with said color
// good for testing purposes
void colorWipe(uint32_t c, uint8_t wait) {
  for (int i=0; i < strip.numPixels(); i++) {
      strip.setPixelColor(i, c);
      strip1.setPixelColor(i, c);
      strip.show();
      strip1.show();
      delay(wait);
  }
}

/* Helper functions */

// Create a 24 bit color value from R,G,B
uint32_t Color(byte r, byte g, byte b)
{
  uint32_t c;
  c = r;
  c <<= 8;
  c |= g;
  c <<= 8;
  c |= b;
  return c;
}

//Input a value 0 to 255 to get a color value.
//The colours are a transition r - g -b - back to r
uint32_t Wheel(byte WheelPos)
{
  if (WheelPos < 85) {
   return Color(WheelPos * 3, 255 - WheelPos * 3, 0);
  } else if (WheelPos < 170) {
   WheelPos -= 85;
   return Color(255 - WheelPos * 3, 0, WheelPos * 3);
  } else {
   WheelPos -= 170; 
   return Color(0, WheelPos * 3, 255 - WheelPos * 3);
  }
}
